# Roles

The language server has extensive support for roles.

(myst-roles-completion)=
## Completion

The most obvious feature is the completion suggestions, try inserting a `{ref}` role on the next line that links to the ``Completion`` heading above.

% Add your reference here...

Notice how VSCode automatically presented you with a list of all the directives you can use in this Sphinx project?
